==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/pl-PL/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Konto z takim adresem e-mail już istnieje.',
    'account_not_found'      => 'Nazwa użytkownika lub hasło jest niepoprawne.',
    'account_not_activated'  => 'Użytkownik jest nieaktywowany.',
    'account_suspended'      => 'Twoje konto zostało zawieszone.',
    'account_banned'         => 'Twoje konto zostało zablokowane.',
    'throttle'               => 'Zbyt wiele nieudanych prób logowania. Spróbuj ponownie za :minutes minut(y).',

    'two_factor' => array(
        'already_enrolled'      => 'Twoje urządzenie jest już zapisane.',
        'success'               => 'Zalogowano pomyślnie.',
        'code_required'         => 'Kod weryfikacji dwuskładnikowej jest wymagany.',
        'invalid_code'          => 'Kod weryfikacji dwuskładnikowej jest nieprawidłowy.',
    ),

    'signin' => array(
        'error'   => 'Wystąpił problem z logowanie, proszę spróbować ponownie.',
        'success' => 'Logowanie poprawne.',
    ),

    'logout' => array(
        'error'   => 'Wystąpił problem podczas wylogowywania, proszę spróbować ponownie.',
        'success' => 'Wylogowano pomyślnie.',
    ),

    'signup' => array(
        'error'   => 'Wystąpił błąd podczas próby utworzenia konta, proszę spróbować ponownie.',
        'success' => 'Konto zostało utworzone.',
    ),

    'forgot-password' => array(
        'error'   => 'Wystąpił błąd podczas próby zresetowania hasła, proszę spróbować ponownie.',
        'success' => 'Jeśli ten adres e-mail istnieje w naszym systemie, e-mail odzyskiwania hasła został wysłany.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Wystąpił błąd podczas próby resetowania hasła, proszę próbować ponownie.',
        'success' => 'Twoje hasło zostało poprawnie zresetowane.',
    ),


);

==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/pl-PL/auth/message.php <==
<?php

return array(

    'account_already_exists' => 'Konto z takim adresem e-mail już istnieje.',
    'account_not_found'      => 'Nazwa użytkownika lub hasło jest niepoprawne.',
    'account_not_activated'  => 'Użytkownik jest nieaktywowany.',
    'account_suspended'      => 'Twoje konto zostało zawieszone.',
    'account_banned'         => 'Twoje konto zostało zablokowane.',
    'throttle'               => 'Zbyt wiele nieudanych prób logowania. Spróbuj ponownie za :minutes minut(y).',

    'two_factor' => array(
        'already_enrolled'      => 'Twoje urządzenie jest już zapisane.',
        'success'               => 'Zalogowano pomyślnie.',
        'code_required'         => 'Kod weryfikacji dwuskładnikowej jest wymagany.',
        'invalid_code'          => 'Kod weryfikacji dwuskładnikowej jest nieprawidłowy.',
        'enter_two_factor_code' => 'Wprowadź kod uwierzytelniania dwuskładnikowego.',
        'please_enroll'         => 'Please enroll a device in two-factor authentication.',
    ),

    'signin' => array(
        'error'   => 'Wystąpił problem z logowanie, proszę spróbować ponownie.',
        'success' => 'Logowanie poprawne.',
    ),

    'logout' => array(
        'error'   => 'Wystąpił problem podczas wylogowywania, proszę spróbować ponownie.',
        'success' => 'Wylogowano pomyślnie.',
    ),

    'signup' => array(
        'error'   => 'Wystąpił błąd podczas próby utworzenia konta, proszę spróbować ponownie.',
        'success' => 'Konto zostało utworzone.',
    ),

    'forgot-password' => array(
        'error'   => 'Wystąpił błąd podczas próby zresetowania hasła, proszę spróbować ponownie.',
        'success' => 'Jeśli ten adres e-mail istnieje w naszym systemie, e-mail odzyskiwania hasła został wysłany.',
    ),

    'forgot-password-confirm' => array(
        'error'   => 'Wystąpił błąd podczas próby resetowania hasła, proszę próbować ponownie.',
        'success' => 'Twoje hasło zostało poprawnie zresetowane.',
    ),


);
